<template>
  <!-- 备品件添加 -->
  <div>
    <el-dialog
      :title="title + '勤务小队信息'"
      :visible.sync="showFormDia"
      width="60%"
      :before-close="handleClose"
      custom-class="bbsl-location-dialog"
      top="8vh"
    >
      <div class="bbsl-scroll-pane">
        <el-form ref="formInfo" class="bbsl-scroll-form-spare" :rules="rules" :model="params" label-width="120px">
          <p id="step1" class="from-title">
            <i class="el-icon-info" />
            <span>基本信息</span>
          </p>

          <el-row>
            <el-col :span="12">
              <el-form-item label="组编号" prop="code">
                <el-input
                  v-model="params.code"
                  maxlength="32"
                  :disabled="true"
                />
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="归属部门" prop="orgId">
                <SelectTree
                  ref="selectTree"
                  v-model="params.orgId"
                  style="width:100%"
                  disabled
                  :options="orgList"
                />
              </el-form-item>
            </el-col>

            <el-col :span="12">
              <el-form-item label="负责人" prop="headman">
                <el-input
                  v-model="params.headman"
                  placeholder="请输入负责人"
                  maxlength="100"
                  show-word-limit
                />
              </el-form-item>
            </el-col>
          </el-row>

          <el-row>

            <el-col :span="12">
              <el-form-item label="组名称" prop="name">
                <el-input
                  v-model="params.name"
                  maxlength="100"
                  show-word-limit
                  clearable
                  placeholder="请输入小组名称"
                />
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="组别名" prop="alias">
                <el-input
                  v-model="params.alias"
                  maxlength="100"
                  show-word-limit
                  clearable
                  placeholder="请输入小组别名"
                />
              </el-form-item>
            </el-col>
          </el-row>
          <!-- <el-row>
            <el-col :span="12">
              <el-form-item label="排序号" prop="sn">
                <el-input-number
                  v-model="params.sn"
                  :max="999999"
                  clearable
                  placeholder="请输入排序号"
                />
              </el-form-item>
            </el-col>
          </el-row> -->
          <el-form-item label="负责区域" prop="area">
            <el-input
              v-model="params.area"
              type="textarea"
              maxlength="500"
              show-word-limit
              :autosize="{minRows: 3, maxRows: 4}"
              placeholder="请输入负责区域"
            />
          </el-form-item>
          <el-form-item label="备注" prop="memo">
            <el-input
              v-model="params.memo"
              maxlength="500"
              show-word-limit
              type="textarea"
              :autosize="{minRows: 3, maxRows: 4}"
              placeholder="请输入备注内容"
            />
          </el-form-item>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import TeamManage from '@/api/manager/duty/teamManage.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CommonApi from '@/views/Manage/CommonApi.js'
import SelectTree from '@/views/Manage/components/SelectTree'

import PY from '@/views/Manage/components/PY.js'

export default {
  name: 'TeamManageDialog',
  components: {
    SelectTree
  },
  props: {},
  data() {
    return {
      title: '新增',
      showFormDia: false,
      fuelTypes: [],
      vehicleTypes: [],
      params: {
        code: '',
        name: '',
        memo: '',
        id: null,
        headman: '',
        area: '',
        pkVal: '',
        sn: 0,
        version: 0,
        orgId: '',
        orgName: '',
        alias: ''
      },
      rules: {
        code: [{
          required: true,
          message: '请输入小组编号',
          trigger: 'blur'
        }],
        name: [{
          required: true,
          message: '请输入小组名称',
          trigger: 'blur'
        }]
      },
      orgList: []
    }
  },
  created() {
    this.loadOrg()
  },
  methods: {
    loadOrg() {
      //   CommonApi.loadSelectOptions({ name: 'manageCommonService.findZGJOrg' }, res => {
      //     this.orgList = res
      //   })

      CommonApi.getAllOrgTree(res => {
        console.log('============res========', res)
        this.orgList = res.data
      })
    },
    add(v) {
      this.params.orgId = v.value
      CommonApi.getNextCodeByAlias('qwxzbh', res => {
        this.params.code = res.value + PY.getCamelChars(v.label)
        this.showFormDia = true
      })
    },
    handleClose() {
      this.params = {
        code: '',
        name: '',
        alias: '',
        memo: '',
        headman: '',
        area: '',
        sn: 0,
        version: 0,
        orgId: '',
        orgName: ''
      }
      this.title = '新增'
      this.showFormDia = false
    },
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          let method
          if (!this.params.id) {
            // 新增
            method = TeamManage.addTeam
          }
          if (this.params.id) {
            // 修改
            method = TeamManage.editTeam
          }
          this.params.orgName = this.$refs.selectTree.valueTitle

          method(this.params, res => {
            if (res.state) {
              this.$notify({
                type: 'success',
                message: this.title + '成功',
                duration: 2000
              })
              this.$parent.loadData(1)
              this.handleClose()
            } else {
              this.$message.warning(res.message)
            }
          })
        }
      })
    },
    Update(row) {
      console.log(row)
      this.title = '修改'
      this.showFormDia = true
      this.params = row

      //   CommonApi.getNextCodeByAlias('qwxzbh', res => {
      //     this.params.code = res.value + PY.getCamelChars(this.params.name)
      //     this.showFormDia = true
      //   })
    }
  }
}
</script>
<style lang="scss" scoped>
.redBull {
  border: 1px solid red;
}

.bbsl-scroll-form-spare {
  width: calc(100% - 20px);
  height: calc(95vh - 420px);
  overflow-y: auto;
  padding: 0 10px;
}
</style>
